@@ -11,6 +11,7 @@ from __future__ import unicode_literals
 
 import json
 import sys
+from collections import OrderedDict
 
 import mock
 import pytest
@@ -133,11 +134,11 @@ def test_default_cli_flags_with_timeout(minion_id, config_dir, config_file, cli_
         sys.executable,
         cli_script_name,
         "--config-dir={}".format(config_dir.strpath),
+        "--timeout={}".format(default_timeout - 5),
         "--out=json",
         "--log-level=quiet",
         minion_id,
         "test.ping",
-        "--timeout={}".format(default_timeout - 5),
     ]
     proc = SaltScriptBase(cli_script_name, config=config, default_timeout=default_timeout)
     # We set __cli_timeout_supported__ to True just to test. This would be an attribute set
@@ -200,11 +201,11 @@ def test_default_cli_flags_with_timeout_and_timeout_kwargs(
         sys.executable,
         cli_script_name,
         "--config-dir={}".format(config_dir.strpath),
+        "--timeout={}".format(explicit_timeout),
         "--out=json",
         "--log-level=quiet",
         minion_id,
         "test.ping",
-        "--timeout={}".format(explicit_timeout),
     ]
 
     popen_mock = mock.MagicMock()
@@ -233,11 +234,11 @@ def test_default_cli_flags_with_timeout_and_timeout_kwargs(
         sys.executable,
         cli_script_name,
         "--config-dir={}".format(config_dir.strpath),
+        "--timeout={}".format(default_timeout - 5),
         "--out=json",
         "--log-level=quiet",
         minion_id,
         "test.ping",
-        "--timeout={}".format(default_timeout - 5),
     ]
 
     popen_mock = mock.MagicMock()
@@ -334,6 +335,32 @@ def test_override_timeout_bad_value(minion_id, config_dir, config_file, cli_scri
     assert proc._terminal_timeout == flag_value
 
 
+@pytest.mark.parametrize("flag", ["-c", "--config-dir", "--config-dir=", None])
+def test_override_config_dir(minion_id, config_dir, config_file, cli_script_name, flag):
+    passed_config_dir = config_dir.strpath + ".new"
+    if flag is None:
+        flag_overrides_args = ["--config-dir={}".format(config_dir.strpath)]
+    elif flag.endswith("="):
+        flag_overrides_args = [flag + passed_config_dir]
+    else:
+        flag_overrides_args = [flag, passed_config_dir]
+
+    default_timeout = 10
+    config = {"conf_file": config_file}
+    args = flag_overrides_args + ["test.ping"]
+    kwargs = {"minion_tgt": minion_id}
+    expected = (
+        [sys.executable, cli_script_name, "--out=json", "--log-level=quiet", minion_id,]
+        + flag_overrides_args
+        + ["test.ping",]
+    )
+    proc = SaltScriptBase(cli_script_name, config=config)
+    # We set the _terminal_timeout attribute just to test. This attribute would be set when calling
+    # SaltScriptBase.run() but we don't really want to call it
+    cmdline = proc.build_cmdline(*args, **kwargs)
+    assert cmdline == expected
+
+
 def test_process_output(cli_script_name):
     in_stdout = '"The salt master could not be contacted. Is master running?"\n'
     in_stderr = ""
@@ -343,3 +370,91 @@ def test_process_output(cli_script_name):
     assert stdout == json.loads(in_stdout)
     assert stderr == in_stderr
     assert json_out is None
+
+
+def test_jsonify_kwargs(minion_id, config_dir, config_file, cli_script_name):
+    config = {"conf_file": config_file}
+    args = ["test.ping"]
+    # Strings
+    extra_kwargs = OrderedDict((("look", "Ma"), ("no", "Hands!")))
+    kwargs = OrderedDict((("minion_tgt", minion_id),))
+    kwargs.update(extra_kwargs)
+    expected = [
+        sys.executable,
+        cli_script_name,
+        "--config-dir={}".format(config_dir.strpath),
+        "--out=json",
+        "--log-level=quiet",
+        minion_id,
+        "test.ping",
+    ]
+    for key, value in extra_kwargs.items():
+        expected.append("{}={}".format(key, value))
+    proc = SaltScriptBase(cli_script_name, config=config)
+    cmdline = proc.build_cmdline(*args, **kwargs)
+    # Function **kwargs are not orderred dictionaries on some python versions
+    # let's just use sorted to make sure everything is in the output
+    assert sorted(cmdline) == sorted(expected)
+
+    # Numbers
+    extra_kwargs = OrderedDict((("width", 1.27), ("height", 3)))
+    kwargs = OrderedDict((("minion_tgt", minion_id),))
+    kwargs.update(extra_kwargs)
+    expected = [
+        sys.executable,
+        cli_script_name,
+        "--config-dir={}".format(config_dir.strpath),
+        "--out=json",
+        "--log-level=quiet",
+        minion_id,
+        "test.ping",
+    ]
+    for key, value in extra_kwargs.items():
+        value = json.dumps(value)
+        expected.append("{}={}".format(key, value))
+    proc = SaltScriptBase(cli_script_name, config=config)
+    cmdline = proc.build_cmdline(*args, **kwargs)
+    # Function **kwargs are not orderred dictionaries on some python versions
+    # let's just use sorted to make sure everything is in the output
+    assert sorted(cmdline) == sorted(expected)
+
+    # Booleans
+    extra_kwargs = OrderedDict((("short", False), ("tall", True)))
+    kwargs = OrderedDict((("minion_tgt", minion_id),))
+    kwargs.update(extra_kwargs)
+    expected = [
+        sys.executable,
+        cli_script_name,
+        "--config-dir={}".format(config_dir.strpath),
+        "--out=json",
+        "--log-level=quiet",
+        minion_id,
+        "test.ping",
+    ]
+    for key, value in extra_kwargs.items():
+        value = json.dumps(value)
+        expected.append("{}={}".format(key, value))
+    proc = SaltScriptBase(cli_script_name, config=config)
+    cmdline = proc.build_cmdline(*args, **kwargs)
+    # Function **kwargs are not orderred dictionaries on some python versions
+    # let's just use sorted to make sure everything is in the output
+    assert sorted(cmdline) == sorted(expected)
+
+    # JSon structure
+    extra_kwargs = {"look": "Ma", "no": "Hands!"}
+    kwargs = {"minion_tgt": minion_id, "extra": extra_kwargs}
+    expected = [
+        sys.executable,
+        cli_script_name,
+        "--config-dir={}".format(config_dir.strpath),
+        "--out=json",
+        "--log-level=quiet",
+        minion_id,
+        "test.ping",
+        "extra={}".format(json.dumps(extra_kwargs)),
+    ]
+    proc = SaltScriptBase(cli_script_name, config=config)
+    cmdline = proc.build_cmdline(*args, **kwargs)
+    # Function **kwargs are not orderred dictionaries on some python versions
+    # let's just use sorted to make sure everything is in the output
+    assert sorted(cmdline) == sorted(expected)
